import { csv, select } from 'd3';//Importing csv,select from D3
import { scatterPlot } from './scatterPlot';
//importing scatterplot modules 
const csvUrl = 'https://gist.githubusercontent.com/curran/a08a1080b88344b0c8a7/raw/0e7a9b0a5d22642a06d3d5b9bcbad9890c8ee534/iris.csv';
const parseRow = (d) => {
  d.sepal_length = +d.sepal_length;
  d.sepal_width = +d.sepal_width;
  d.petal_length = +d.petal_length;
  d.petal_width = +d.petal_width;
  return d;
}; // Collecting annd parsing 

const width = window.innerWidth;// size of window width	
const height = window.innerHeight;// size of window height
const svg = select('body')
  .append('svg')
  .attr('width', width)
  .attr('height', height);

const xValue = (d) => d.petal_length;
const yValue = (d) => d.petal_width;
const rxValue = (d) => d.sepal_length;
const ryValue = (d) => d.sepal_width;      
const group = (d) => d.species;
// adding all the constant values
const main = async () => {
  const data = await csv(csvUrl, parseRow);
  
  const x = xValue((d) => d.petal_width);
        
  const y = yValue((d) => d.sepal_length);
  
  const color = d3.scaleOrdinal()
    .domain(["setosa", "versicolor", "virginica" ]) //  Different attributes
    .range([ "blue", "green", "red"]); // color 
  
  const marks = data.map((d) => ({
          x: xValue((d) => d.petal_width),
          y: yValue((d) => d.sepal_length),
          color: color(group(d)),
        	rx: rxValue(d),
          ry: ryValue(d),
                      
        })); //  providing marks 
  
  const plot = scatterPlot()
    .width(width)
    .height(height)
    .data(await csv(csvUrl, parseRow))
    .xValue((d) => d.petal_width)
    .yValue((d) => d.sepal_length)
    .margin({
      top: 20,
      right: 130,
      bottom: 40,
      left: 50, 
    }) // alignmenting scatter plot
    .radius(5);  // radius of the circles
  
    const legend = svg.selectAll('legend')
      .data(color.domain())
      .enter().append('g')
      .attr('class', 'legend')
      .attr('transform', function(d,i){ return 'translate(0,' + i * 20 + ')'; });

    legend.append('rect')
      .attr('x', width-20)
      .attr('width', 18)
      .attr('height', 18)
      .style('fill', color);// legends with width,height,color and position

    legend.append('text')
    .attr('x', width - 26)
    .attr('y', 9)
    .attr('dy', '.35em')
    .style('text-anchor', 'end')
    .attr("font-family", "Arial, Helvetica, sans-serif")
    .text(function(d){ return d; });
	  // alignment of text 
  
		svg.selectAll('circle')
          .data(marks)
          .join('circle')
          .attr('cx', (d) => d.x)
          .attr('cy', (d) => d.y)
        	.attr('fill', (d) => d.color)
        	.attr('rx', (d) => (d.rx))
        	.attr('ry', (d) => (d.ry)); // making circle nice shape
  	
  	    svg.append("text")
        .attr("x",-111)
        .attr("y",20)
        .attr("font-size","14px")
        .attr("transform","rotate(-90)")
        .text("Sepal Length")    //adding the Y lable 
        
       
    svg.append("text")
        .attr("x",800)
        .attr("y",500)
        .attr("font-size","14px")
        .text("Petal width")  // adding the X lable
  
  const columns = [
    'petal_width',
    'sepal_width',
    'petal_length',
    'sepal_length',
  ];
  let i = 0;
  setInterval(() => {
    plot.xValue((d) => d[columns[i % columns.length]]);
    svg.call(plot);
    i++;
  }, 2000); // interval for reusable scatter plot 
};
main();
